California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 39 - SCHOOL FACILITIES. 55% LOCAL VOTE. BONDS, TAXES. ACCOUNTABILITY REQUIREMENTS. INITIATIVE CONSTITUTIONAL AMENDMENT AND STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1222562 | TAXPAYERS FOR ACCOUNTABILITY AND BETTER SCHOOLS (TABS), YES ON PROPOSITION 39, A COALITION OF TEACHERS, PARENTS, SENIORS, TAXPAYERS AND BUSINESS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
922117 | SAVE OUR HOMES COMMITTEE, VOTE NO ON PROP. 39, A PROJECT OF THE HOWARD JARVIS TAXPAYERS ASSOCIATION | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1225973 | CALIFORNIANS FOR BETTER PUBLIC SCHOOLS AND FOR PROP 39 AND AGAINST 38 | SUPPORT